summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Spencer <markster@digium.com>2003-07-01 20:26:22 +0000
committerMark Spencer <markster@digium.com>2003-07-01 20:26:22 +0000
commite9cffc55a7b84c6d356283b9167882cc59c950e5 (patch)
treef01fcdd02d6c90873da544b2f0f3fc4fbb2536a5
parent81fc3f26fa56df0830f18ec6f9974228e09b6304 (diff)
Update for sendingcomplete
git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@1148 65c4cc65-6c06-0410-ace0-fbb531ad65f3
-rwxr-xr-xchannels/chan_zap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/channels/chan_zap.c b/channels/chan_zap.c
index 1c1e95838..376d5e65c 100755
--- a/channels/chan_zap.c
+++ b/channels/chan_zap.c
@@ -5607,10 +5607,10 @@ static void *pri_dchannel(void *vpri)
strcpy(pri->pvt[chan]->callerid, "");
strncpy(pri->pvt[chan]->rdnis, e->ring.redirectingnum, sizeof(pri->pvt[chan]->rdnis));
}
- /* If immediate=yes go to s|1 */
- if (pri->pvt[chan]->immediate) {
+ /* If immediate=yes or call complete go to s|1 */
+ if (pri->pvt[chan]->immediate || e->ring.complete) {
if (option_verbose > 2)
- ast_verbose(VERBOSE_PREFIX_3 "Going to extension s|1 because of immediate=yes\n");
+ ast_verbose(VERBOSE_PREFIX_3 "Going to extension s|1 because of immediate=yes or Complete received\n");
strcpy(pri->pvt[chan]->exten, "s");
}
/* Get called number */